==> ministra-5.6.8.zip: stalker_portal/server/Lib/Watchdog.php <==
<?php

namespace Ministra\Lib;

use Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\E0f1497c1499ac20875f2ad18485909a9;
use Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\f1861167937df2425a26a0c9763b3b8f;
use Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a;
class Watchdog extends \Ministra\Lib\AjaxResponse implements \Ministra\Lib\StbApi\Watchdog
{
    public function __construct()
    {
        parent::__construct();
    }
    public function getEvents()
    {
        $just_started = isset($_REQUEST['init']) ? (int) $_REQUEST['init'] : 0;
        if (isset($_REQUEST['init']) && \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\E0f1497c1499ac20875f2ad18485909a9::getSafe('log_mac_clones', false) && $just_started == 0 && \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a::getInstance()->getMTVParam('just_started') == 0) {
            $clone_ip = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\f1861167937df2425a26a0c9763b3b8f::n1c67fb9ac373a9ba5da28ee7bbbc46b9();
            if ($clone_ip) {
                \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a::y333cb4c24d1e689912b44cd0d393f1bb($clone_ip);
            }
        }
        if ($this->stb->getMTVParam('ip') != $this->stb->ip) {
            $user = \Ministra\Lib\User::getInstance($this->stb->id);
            $user->getInfoFromOSS();
        }
        $this->db->update('users', ['keep_alive' => 'NOW()', 'ip' => $this->stb->ip, 'now_playing_type' => (int) $_REQUEST['cur_play_type'], 'just_started' => $just_started, 'last_watchdog' => 'NOW()'], ['mac' => $this->stb->mac]);
        $events = \Ministra\Lib\Event::getAllNotEndedEvents($this->stb->id);
        $messages = \is_array($events) ? \count($events) : 0;
        $res['data'] = [];
        $res['data']['msgs'] = $messages;
        if ($messages > 0) {
            if ($events[0]['sended'] == 0) {
                \Ministra\Lib\Event::setSended($events[0]['id']);
                if ($events[0]['need_confirm'] == 0) {
                    \Ministra\Lib\Event::setEnded($events[0]['id']);
                }
            }
            if ($events[0]['id'] != @$_GET['data']['event_active_id']) {
                $res['data']['id'] = $events[0]['id'];
                $res['data']['event'] = $events[0]['event'];
                $res['data']['need_confirm'] = $events[0]['need_confirm'];
                $res['data']['msg'] = $events[0]['msg'];
                $res['data']['reboot_after_ok'] = $events[0]['reboot_after_ok'];
                $res['data']['auto_hide_timeout'] = $events[0]['auto_hide_timeout'];
                $res['data']['post_function'] = $events[0]['post_function'];
                $res['data']['param1'] = $events[0]['param1'];
                $res['data']['valid_until'] = \strtotime($events[0]['eventtime']);
                if (\Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\E0f1497c1499ac20875f2ad18485909a9::getSafe('display_send_time_in_message', false)) {
                    $res['data']['send_time'] = $events[0]['addtime'];
                }
            }
        }
        $res['data']['additional_services_on'] = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\E0f1497c1499ac20875f2ad18485909a9::getSafe('enable_tariff_plans', false) ? '1' : $this->stb->additional_services_on;
        return $res;
    }
    public function confirmEvent()
    {
        \Ministra\Lib\Event::setConfirmed((int) $_REQUEST['event_active_id']);
        $res['data'] = 'ok';
        return $res;
    }
}

==> ministra-5.6.10.zip: stalker_portal/server/Lib/Watchdog.php <==
<?php

namespace Ministra\Lib;

use Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g58b21ad8584095b442bb4ed404e99dce;
use Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\B91ebc4a2170a66056f8eac1009f6bb85;
use Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca;
class Watchdog extends \Ministra\Lib\AjaxResponse implements \Ministra\Lib\StbApi\Watchdog
{
    public function __construct()
    {
        parent::__construct();
    }
    public function getEvents()
    {
        $just_started = isset($_REQUEST['init']) ? (int) $_REQUEST['init'] : 0;
        if (isset($_REQUEST['init']) && \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g58b21ad8584095b442bb4ed404e99dce::getSafe('log_mac_clones', false) && $just_started == 0 && \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::getInstance()->getMTVParam('just_started') == 0) {
            $clone_ip = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\B91ebc4a2170a66056f8eac1009f6bb85::be20dedae08532bc7e8b90d943c9c252();
            if ($clone_ip) {
                \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::t3f1b6c27a6e5e1dcdcffb7717acc2040($clone_ip);
            }
        }
        if ($this->stb->getMTVParam('ip') != $this->stb->ip) {
            $user = \Ministra\Lib\User::getInstance($this->stb->id);
            $user->getInfoFromOSS();
        }
        $this->db->update('users', ['keep_alive' => 'NOW()', 'ip' => $this->stb->ip, 'now_playing_type' => (int) $_REQUEST['cur_play_type'], 'just_started' => $just_started, 'last_watchdog' => 'NOW()'], ['mac' => $this->stb->mac]);
        $events = \Ministra\Lib\Event::getAllNotEndedEvents($this->stb->id);
        $messages = \is_array($events) ? \count($events) : 0;
        $res['data'] = [];
        $res['data']['msgs'] = $messages;
        if ($messages > 0) {
            if ($events[0]['sended'] == 0) {
                \Ministra\Lib\Event::setSended($events[0]['id']);
                if ($events[0]['need_confirm'] == 0) {
                    \Ministra\Lib\Event::setEnded($events[0]['id']);
                }
            }
            if ($events[0]['id'] != @$_GET['data']['event_active_id']) {
                $res['data']['id'] = $events[0]['id'];
                $res['data']['event'] = $events[0]['event'];
                $res['data']['need_confirm'] = $events[0]['need_confirm'];
                $res['data']['msg'] = $events[0]['msg'];
                $res['data']['reboot_after_ok'] = $events[0]['reboot_after_ok'];
                $res['data']['auto_hide_timeout'] = $events[0]['auto_hide_timeout'];
                $res['data']['post_function'] = $events[0]['post_function'];
                $res['data']['param1'] = $events[0]['param1'];
                $res['data']['valid_until'] = \strtotime($events[0]['eventtime']);
                if (\Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g58b21ad8584095b442bb4ed404e99dce::getSafe('display_send_time_in_message', false)) {
                    $res['data']['send_time'] = $events[0]['addtime'];
                }
            }
        }
        $res['data']['additional_services_on'] = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g58b21ad8584095b442bb4ed404e99dce::getSafe('enable_tariff_plans', false) ? '1' : $this->stb->additional_services_on;
        return $res;
    }
    public function confirmEvent()
    {
        \Ministra\Lib\Event::setConfirmed((int) $_REQUEST['event_active_id']);
        $res['data'] = 'ok';
        return $res;
    }
}
